###################################################
### chunk number 1: 
###################################################
library(qualityTools)


###################################################
### chunk number 2: 
###################################################
#create artificial defect data set
defects = c(rep("E", 62), rep("B", 15), rep("F", 3), rep("A", 10),
rep("C",20), rep("D", 10))
paretoChart(defects)


###################################################
### chunk number 3: 
###################################################
x = c(9.991, 10.013, 10.001, 10.007, 10.010, 10.013, 10.008, 10.017, 10.005,
10.005, 10.002, 10.017, 10.005, 10.002,  9.996, 10.011, 10.009, 10.006,
10.008, 10.003, 10.002, 10.006, 10.010, 9.992, 10.013)
cg(x, target = 10.003, tolerance = c(9.903, 10.103))


###################################################
### chunk number 4: 
###################################################
#create a gage RnR design
design = gageRRDesign(Operators=3, Parts=10, Measurements=2, randomize=FALSE)
#set the response	
response(design) = c(23,22,22,22,22,25,23,22,23,22,20,22,22,22,24,25,27,28,
23,24,23,24,24,22,22,22,24,23,22,24,20,20,25,24,22,24,21,20,21,22,21,22,21,
21,24,27,25,27,23,22,25,23,23,22,22,23,25,21,24,23)
#perform Gage RnR
gdo = gageRR(design)


###################################################
### chunk number 5: GageRR
###################################################
#visualization of Gage RnR
plot(gdo)


###################################################
### chunk number 6: 
###################################################
#visualization of Gage RnR
plot(gdo)


###################################################
### chunk number 7: NormPcr
###################################################
set.seed(1234)
#generate some data
norm = rnorm(20, mean = 20)
#generate some data
weib = rweibull(20, shape = 2, scale = 8)
#process capability
pcr(norm, "normal", lsl = 17, usl = 23)


###################################################
### chunk number 8: WeibPcr
###################################################
#process cabapility
pcr(weib, "weibull", usl = 20)


###################################################
### chunk number 9: 
###################################################
set.seed(1234)
#generate some data
norm = rnorm(20, mean = 20)
#generate some data
weib = rweibull(20, shape = 2, scale = 8)
#process capability
pcr(norm, "normal", lsl = 17, usl = 23)


###################################################
### chunk number 10: 
###################################################
#process cabapility
pcr(weib, "weibull", usl = 20)


###################################################
### chunk number 11: 
###################################################
pcr(weib, "weibull", usl = 20)


###################################################
### chunk number 12: qqPlot
###################################################
par(mfrow = c(1,2))
qqPlot(weib, "weibull"); qqPlot(weib, "normal")


###################################################
### chunk number 13: 
###################################################
par(mfrow = c(1,2))
qqPlot(weib, "weibull"); qqPlot(weib, "normal")


###################################################
### chunk number 14: ppPlot
###################################################
par(mfrow = c(1,2))
ppPlot(norm, "weibull"); ppPlot(norm, "normal")


###################################################
### chunk number 15: 
###################################################
par(mfrow = c(1,2))
ppPlot(norm, "weibull"); ppPlot(norm, "normal")


###################################################
### chunk number 16: 
###################################################
set.seed(1234)
fdo = facDesign(k = 3, centerCube = 4) #fdo - factorial design object
names(fdo) = c("Factor 1", "Factor 2", "Factor 3") #optional
lows(fdo) = c(80, 120, 1) #optional
highs(fdo) = c(120, 140, 2) #optional
summary(fdo) #information about the factorial design


###################################################
### chunk number 17: 
###################################################
#set first value
yield = simProc(x1 = 80, x2 = 120, x3 = 1)


###################################################
### chunk number 18: 
###################################################
yield = c(simProc(80,120, 1),simProc(120,120, 2),simProc(120,140, 2),
simProc(80,140, 1),simProc(120,120, 1),simProc(120,140, 1),
simProc(80,120, 2),simProc(80,140, 2), simProc(90,130, 1.5),
simProc(90,130, 1.5),simProc(90,130, 1.5), simProc(90,130, 1.5))


###################################################
### chunk number 19: 
###################################################
response(fdo) = yield	#assign yield to the factorial design object


###################################################
### chunk number 20: effPlot
###################################################
effectPlot(fdo, classic = TRUE)


###################################################
### chunk number 21: iaPlot
###################################################
interactionPlot(fdo)


###################################################
### chunk number 22: 
###################################################
effectPlot(fdo, classic = TRUE)


###################################################
### chunk number 23: 
###################################################
interactionPlot(fdo)


###################################################
### chunk number 24: 
###################################################
lm.1 = lm(yield ~ A*B*C, data = fdo)
summary(lm.1)


###################################################
### chunk number 25: ParetPlot
###################################################
paretoPlot(fdo)


###################################################
### chunk number 26: 
###################################################
paretoPlot(fdo)


###################################################
### chunk number 27: wirePlot
###################################################
par(mfrow = c(1,2))
wirePlot(A, B, yield, data = fdo)
contourPlot(A, B, yield, data = fdo)


###################################################
### chunk number 28: 
###################################################
par(mfrow = c(1,2))
wirePlot(A, B, yield, data = fdo)
contourPlot(A, B, yield, data = fdo)


###################################################
### chunk number 29: 
###################################################
fdo.frac = fracDesign(k = 3, gen = "C = AB", centerCube = 4)


###################################################
### chunk number 30: 
###################################################
summary(fdo.frac)


###################################################
### chunk number 31: 
###################################################
aliasTable(fdo.frac)


###################################################
### chunk number 32: fracChoose
###################################################
fracChoose()


###################################################
### chunk number 33: 
###################################################
fracChoose()


###################################################
### chunk number 34: 
###################################################
fdo1 = facDesign(k = 3, centerCube = 2, replicates = 2)


###################################################
### chunk number 35: 
###################################################
set.seed(1234)
y2 = rnorm(12, mean = 20)
response(fdo) = data.frame(yield, y2) 


###################################################
### chunk number 36: multiresp
###################################################
par(mfrow = c(1,2))
wirePlot(A, B, yield, data = fdo, form = "yield~A+B+C+A*B")
contourPlot(A, B, y2, data = fdo, form = "y2~A+B+C+A*B")


###################################################
### chunk number 37: 
###################################################
par(mfrow = c(1,2))
wirePlot(A, B, yield, data = fdo, form = "yield~A+B+C+A*B")
contourPlot(A, B, y2, data = fdo, form = "y2~A+B+C+A*B")


###################################################
### chunk number 38: multiresp2
###################################################
par(mfrow = c(1,2))
wirePlot(A,B,y2, data = fdo, factors = list(C=-1), form = "y2~A*B*C")
wirePlot(A,B,y2, data = fdo, factors = list(C=1), form = "y2~A*B*C")


###################################################
### chunk number 39: 
###################################################
par(mfrow = c(1,2))
wirePlot(A,B,y2, data = fdo, factors = list(C=-1), form = "y2~A*B*C")
wirePlot(A,B,y2, data = fdo, factors = list(C=1), form = "y2~A*B*C")


###################################################
### chunk number 40: 
###################################################
fits(fdo) = lm(yield ~ A+B, data = fdo)
fits(fdo) = lm(y2 ~ A*B*C, data = fdo)
fits(fdo)


###################################################
### chunk number 41: 
###################################################
sao =steepAscent(factors=c("A","B"),response="yield",data=fdo,steps=20)
sao


###################################################
### chunk number 42: steepAsc
###################################################
predicted = simProc(sao[,5], sao[,6])
response(sao) = predicted 
plot(sao, type = "b", col = 2)


###################################################
### chunk number 43: 
###################################################
predicted = simProc(sao[,5], sao[,6])
response(sao) = predicted 
plot(sao, type = "b", col = 2)


###################################################
### chunk number 44: 
###################################################
#set the seed for randomization of the runs
set.seed(1234)
fdo2 = facDesign(k = 2, centerCube = 3)
names(fdo2) = c("Factor 1", "Factor 2") 
lows(fdo2) = c(134, 155)
highs(fdo2) = c(155, 175)


###################################################
### chunk number 45: 
###################################################
yield = c(simProc(134,155), simProc(155,155), simProc(134,175),
simProc(155,175),simProc(144,165), simProc(144,165), simProc(144,165))
response(fdo2) = yield


###################################################
### chunk number 46: 
###################################################
rsdo = starDesign(data = fdo2)


###################################################
### chunk number 47: 
###################################################
yield2 = c(yield, simProc(130,165), simProc(149,165), simProc(144,151),
simProc(144,179),simProc(144,165),simProc(144,165),simProc(144,165))
response(rsdo) = yield2


###################################################
### chunk number 48: 
###################################################
lm.3 = lm(yield2 ~ A*B + I(A^2) + I(B^2), data = rsdo)


###################################################
### chunk number 49: respSur
###################################################
par(mfrow=c(1,2))
wirePlot(A,B,yield2,form="yield2~A*B+I(A^2)+I(B^2)",data=rsdo,theta=-70)
contourPlot(A,B,yield2,form="yield2~A*B+I(A^2)+I(B^2)",data=rsdo)


###################################################
### chunk number 50: 
###################################################
par(mfrow=c(1,2))
wirePlot(A,B,yield2,form="yield2~A*B+I(A^2)+I(B^2)",data=rsdo,theta=-70)
contourPlot(A,B,yield2,form="yield2~A*B+I(A^2)+I(B^2)",data=rsdo)


###################################################
### chunk number 51: 
###################################################
A = seq(40, 210, length = 100)
B = seq(90, 190, length = 100)
C = seq(90, 190, length = 100)
filled.contour(A, B,outer(A,B, simProc, noise = FALSE), xlab = "Factor 1", ylab = "Factor 2", color.palette = colorRampPalette(c("#00007F", "blue", "#007FFF", "cyan","#7FFF7F", "yellow", "#FF7F00", "red", "#7F0000"))) 


###################################################
### chunk number 52: 
###################################################
fdo = rsmDesign(k = 3, alpha = 1.633, cc = 0, cs = 6)


###################################################
### chunk number 53: 
###################################################
fdo = randomize(fdo, so = TRUE)


###################################################
### chunk number 54: desTab
###################################################
rsdo = rsmChoose()


###################################################
### chunk number 55: 
###################################################
rsdo = rsmChoose()


###################################################
### chunk number 56: 
###################################################
fdo3 = facDesign(k = 6)
rsdo = starDesign(alpha = "orthogonal", data = fdo3)


###################################################
### chunk number 57: 
###################################################
randomize(fdo, random.seed = 123)


###################################################
### chunk number 58: 
###################################################
d1 = desirability(y1, 120, 170, scale = c(1,1), target = "max")
d3 = desirability(y3, 400, 600, target = 500)
d1


###################################################
### chunk number 59: desirb
###################################################
par(mfrow = c(1,2))
plot(d1, col = 2); plot(d3, col = 2)


###################################################
### chunk number 60: 
###################################################
par(mfrow = c(1,2))
plot(d1, col = 2); plot(d3, col = 2)


###################################################
### chunk number 61: 
###################################################
ddo = rsmDesign(k = 3, alpha = 1.633, cc = 0, cs = 6)
ddo = randomize(ddo, so = TRUE)
#optional
names(ddo) = c("silica", "silan", "sulfur")
#optional
highs(ddo) = c(1.7, 60, 2.8)
#optional
lows(ddo) = c(0.7, 40, 1.8)


###################################################
### chunk number 62: 
###################################################
y1 = c(102, 120, 117, 198, 103, 132, 132, 139, 102, 154, 96, 163, 116,
 153, 133, 133, 140, 142, 145, 142)
y2 = c(900, 860, 800, 2294, 490, 1289, 1270, 1090, 770, 1690, 700, 1540,
 2184, 1784, 1300, 1300, 1145, 1090, 1260, 1344)
y3 = c(470, 410, 570, 240, 640, 270, 410, 380, 590, 260, 520, 380, 520,
 290, 380, 380, 430, 430, 390, 390)
y4 = c(67.5, 65, 77.5, 74.5, 62.5, 67, 78, 70, 76, 70, 63, 75, 65, 71,
 70, 68.5, 68, 68, 69, 70)


###################################################
### chunk number 63: 
###################################################
response(ddo) = data.frame(y1, y2, y3, y4)[c(5,2,3,8,1,6,7,4,9:20),]


###################################################
### chunk number 64: 
###################################################
d2 = desirability(y2, 1000, 1300, target = "max")
d4 = desirability(y4, 60, 75, target = 67.5)


###################################################
### chunk number 65: 
###################################################
desires(ddo)=d1; desires(ddo)=d2; desires(ddo)=d3; desires(ddo)=d4


###################################################
### chunk number 66: 
###################################################
fits(ddo) = lm(y1 ~ A+B+C+A:B+A:C+B:C+I(A^2)+I(B^2)+I(C^2), data = ddo)
fits(ddo) = lm(y2 ~ A+B+C+A:B+A:C+B:C+I(A^2)+I(B^2)+I(C^2), data = ddo)
fits(ddo) = lm(y3 ~ A+B+C+A:B+A:C+B:C+I(A^2)+I(B^2)+I(C^2), data = ddo)
fits(ddo) = lm(y4 ~ A+B+C+A:B+A:C+B:C+I(A^2)+I(B^2)+I(C^2), data = ddo)


###################################################
### chunk number 67: 
###################################################
optimum(ddo, type = "optim")


###################################################
### chunk number 68: 
###################################################
mdo = mixDesign(3,2, center = FALSE, axial = FALSE, randomize = FALSE,
replicates  = c(1,1,2,3))
names(mdo) = c("polyethylene", "polystyrene", "polypropylene")

#set response (i.e. yarn elongation)
elongation = c(11.0, 12.4, 15.0, 14.8, 16.1, 17.7, 16.4, 16.6, 8.8, 10.0,
10.0, 9.7, 11.8, 16.8, 16.0)  
response(mdo) = elongation


###################################################
### chunk number 69: 
###################################################
mdo


###################################################
### chunk number 70: respAcont
###################################################
par(mfrow=c(1,2))
contourPlot3(A, B, C, elongation, data = mdo, form = "quadratic")
wirePlot3(A, B, C, elongation, data=mdo, form="quadratic", theta=-170)


###################################################
### chunk number 71: 
###################################################
par(mfrow=c(1,2))
contourPlot3(A, B, C, elongation, data = mdo, form = "quadratic")
wirePlot3(A, B, C, elongation, data=mdo, form="quadratic", theta=-170)


###################################################
### chunk number 72: 
###################################################
set.seed(1234)
tdo = taguchiDesign("L9_3")
values(tdo) = list(A  = c(20, 40, 60), B = c("mateial 1", "material 2",
"material 3"), C = c(1,2,3))
names(tdo) = c("Factor 1", "Factor 2", "Factor 3", "Factor 4")
summary(tdo)


###################################################
### chunk number 73: taguchi
###################################################
response(tdo) = rnorm(9)
effectPlot(tdo, col = 2)


###################################################
### chunk number 74: 
###################################################
response(tdo) = rnorm(9)
effectPlot(tdo, col = 2)


###################################################
### chunk number 75: 
###################################################
sessionInfo()


